InputRequest

Enum InputRequest 

pub enum InputRequest {
    CreateMessageRequest(CreateMessageRequest),
    ListRootsRequest(ListRootsRequest),
    ElicitRequest(ElicitRequest),
}
Latest MCP Protocol 2026_07_28 InputRequest

JSON schema
{
 "anyOf": [
   {
     "$ref": "#/$defs/CreateMessageRequest"
   },
   {
     "$ref": "#/$defs/ListRootsRequest"
   },
   {
     "$ref": "#/$defs/ElicitRequest"
   }
 ]
}

Variants



CreateMessageRequest(CreateMessageRequest)



ListRootsRequest(ListRootsRequest)



ElicitRequest(ElicitRequest)

Implementations

Source

impl InputRequest

pub fn as_create_message(&self) -> Option<&CreateMessageRequest>

Returns the inner request if this is a sampling/createMessage input request.

pub fn as_list_roots(&self) -> Option<&ListRootsRequest>

Returns the inner request if this is a roots/list input request.

pub fn as_elicit(&self) -> Option<&ElicitRequest>

Returns the inner request if this is an elicitation/create input request.

pub fn method(&self) -> &str

The JSON-RPC method of the wrapped input request (sampling/createMessage, roots/list, or elicitation/create).