pub enum LoggingLevel {
Alert,
Critical,
Debug,
Emergency,
Error,
Info,
Notice,
Warning,
}Expand description
Latest MCP Protocol 2026_07_28 The severity of a log message. These map to syslog message severities, as specified in RFC-5424: https://datatracker.ietf.org/doc/html/rfc5424#section-6.2.1
JSON schema
{
"description": "The severity of a log message.\n\nThese map to syslog message severities, as specified in RFC-5424:\n<https://datatracker.ietf.org/doc/html/rfc5424#section-6.2.1>",
"type": "string",
"enum": [
"alert",
"critical",
"debug",
"emergency",
"error",
"info",
"notice",
"warning"
]
}Variants