pub struct CancelledNotificationParams {
pub meta: Option<NotificationMetaObject>,
pub reason: Option<String>,
pub request_id: RequestId,
}Expand description
Latest MCP Protocol 2026_07_28 Parameters for a notifications/cancelled notification.
JSON schema
{
"description": "Parameters for a notifications/cancelled notification.",
"type": "object",
"required": [
"requestId"
],
"properties": {
"_meta": {
"$ref": "#/$defs/NotificationMetaObject"
},
"reason": {
"description": "An optional string describing the reason for the cancellation. This MAY be logged or presented to the user.",
"type": "string"
},
"requestId": {
"description": "The ID of the request to cancel.\n\nThis MUST correspond to the ID of a request the client previously issued.",
"$ref": "#/$defs/RequestId"
}
}
}Fields
meta: Option<NotificationMetaObject>reason: Option<String>An optional string describing the reason for the cancellation. This MAY be logged or presented to the user.
request_id: RequestIdThe ID of the request to cancel. This MUST correspond to the ID of a request the client previously issued.