pub struct CreateMessageResult {
pub content: CreateMessageContent,
pub meta: Option<MetaObject>,
pub model: String,
pub role: Role,
pub stop_reason: Option<String>,
}Expand description
Latest MCP Protocol 2026_07_28 The result returned by the client for a {@link CreateMessageRequestsampling/createMessage} request. The client should inform the user before returning the sampled message, to allow them to inspect the response (human in the loop) and decide whether to allow the server to see it.
JSON schema
{
"description": "The result returned by the client for a {@link CreateMessageRequestsampling/createMessage} request.\nThe client should inform the user before returning the sampled message, to allow them\nto inspect the response (human in the loop) and decide whether to allow the server to see it.",
"type": "object",
"required": [
"content",
"model",
"role"
],
"properties": {
"_meta": {
"$ref": "#/$defs/MetaObject"
},
"content": {
"anyOf": [
{
"$ref": "#/$defs/TextContent"
},
{
"$ref": "#/$defs/ImageContent"
},
{
"$ref": "#/$defs/AudioContent"
},
{
"$ref": "#/$defs/ToolUseContent"
},
{
"$ref": "#/$defs/ToolResultContent"
},
{
"type": "array",
"items": {
"$ref": "#/$defs/SamplingMessageContentBlock"
}
}
]
},
"model": {
"description": "The name of the model that generated the message.",
"type": "string"
},
"role": {
"$ref": "#/$defs/Role"
},
"stopReason": {
"description": "The reason why sampling stopped, if known.\n\nStandard values:\n- \"endTurn\": Natural end of the assistant's turn\n- \"stopSequence\": A stop sequence was encountered\n- \"maxTokens\": Maximum token limit was reached\n- \"toolUse\": The model wants to use one or more tools\n\nThis field is an open string to allow for provider-specific stop reasons.",
"type": "string"
}
}
}Fields
content: CreateMessageContentmeta: Option<MetaObject>model: StringThe name of the model that generated the message.
role: Rolestop_reason: Option<String>The reason why sampling stopped, if known. Standard values: - “endTurn”: Natural end of the assistant’s turn - “stopSequence”: A stop sequence was encountered - “maxTokens”: Maximum token limit was reached - “toolUse”: The model wants to use one or more tools This field is an open string to allow for provider-specific stop reasons.