pub struct DiscoverResultResponse {
pub id: RequestId,
pub result: DiscoverResult,
/* private fields */
}Expand description
Latest MCP Protocol 2026_07_28 A successful response from the server for a {@link DiscoverRequestserver/discover} request.
JSON schema
{
"description": "A successful response from the server for a {@link DiscoverRequestserver/discover} request.",
"type": "object",
"required": [
"id",
"jsonrpc",
"result"
],
"properties": {
"id": {
"$ref": "#/$defs/RequestId"
},
"jsonrpc": {
"type": "string",
"const": "2.0"
},
"result": {
"$ref": "#/$defs/DiscoverResult"
}
}
}Fields
id: RequestIdresult: DiscoverResultImplementations