pub struct ElicitRequestFormParams {
pub message: String,
pub requested_schema: ElicitRequestFormParamsRequestedSchema,
/* private fields */
}Expand description
Latest MCP Protocol 2026_07_28 The parameters for a request to elicit non-sensitive information from the user via a form in the client.
JSON schema
{
"description": "The parameters for a request to elicit non-sensitive information from the user via a form in the client.",
"type": "object",
"required": [
"message",
"requestedSchema"
],
"properties": {
"message": {
"description": "The message to present to the user describing what information is being requested.",
"type": "string"
},
"mode": {
"description": "The elicitation mode.",
"type": "string",
"const": "form"
},
"requestedSchema": {
"description": "A restricted subset of JSON Schema.\nOnly top-level properties are allowed, without nesting.",
"type": "object",
"required": [
"properties",
"type"
],
"properties": {
"$schema": {
"type": "string"
},
"properties": {
"type": "object",
"additionalProperties": {
"$ref": "#/$defs/PrimitiveSchemaDefinition"
}
},
"required": {
"type": "array",
"items": {
"type": "string"
}
},
"type": {
"type": "string",
"const": "object"
}
}
}
}
}Fields
message: StringThe message to present to the user describing what information is being requested.
requested_schema: ElicitRequestFormParamsRequestedSchemaImplementations