pub struct ElicitRequestUrlParams {
pub message: String,
pub url: String,
/* private fields */
}Expand description
Latest MCP Protocol 2026_07_28 The parameters for a request to elicit information from the user via a URL in the client.
JSON schema
{
"description": "The parameters for a request to elicit information from the user via a URL in the client.",
"type": "object",
"required": [
"message",
"mode",
"url"
],
"properties": {
"message": {
"description": "The message to present to the user explaining why the interaction is needed.",
"type": "string"
},
"mode": {
"description": "The elicitation mode.",
"type": "string",
"const": "url"
},
"url": {
"description": "The URL that the user should navigate to.",
"type": "string",
"format": "uri"
}
}
}Fields
message: StringThe message to present to the user explaining why the interaction is needed.
url: StringThe URL that the user should navigate to.
Implementations