pub struct ElicitationCompleteNotification {
pub params: ElicitCompleteParams,
/* private fields */
}Expand description
Latest MCP Protocol 2025_11_25 An optional notification from the server to the client, informing it of a completion of a out-of-band elicitation request.
JSON schema
{
"description": "An optional notification from the server to the client, informing it of a completion of a out-of-band elicitation request.",
"type": "object",
"required": [
"jsonrpc",
"method",
"params"
],
"properties": {
"jsonrpc": {
"type": "string",
"const": "2.0"
},
"method": {
"type": "string",
"const": "notifications/elicitation/complete"
},
"params": {
"type": "object",
"required": [
"elicitationId"
],
"properties": {
"elicitationId": {
"description": "The ID of the elicitation that completed.",
"type": "string"
}
}
}
}
}Fields
params: ElicitCompleteParamsImplementations