InputRequiredResult

Struct InputRequiredResult 

pub struct InputRequiredResult {
    pub input_requests: Option<InputRequests>,
    pub meta: Option<ResultMetaObject>,
    pub request_state: Option<String>,
    pub result_type: String,
}
Latest MCP Protocol 2026_07_28 An InputRequiredResult sent by the server to indicate that additional input is needed before the request can be completed. At least one of inputRequests or requestState MUST be present.

JSON schema
{
 "description": "An InputRequiredResult sent by the server to indicate that additional input is needed\nbefore the request can be completed.\n\nAt least one of inputRequests or requestState MUST be present.",
 "type": "object",
 "required": [
   "resultType"
 ],
 "properties": {
   "_meta": {
     "$ref": "#/$defs/ResultMetaObject"
   },
   "inputRequests": {
     "$ref": "#/$defs/InputRequests"
   },
   "requestState": {
     "type": "string"
   },
   "resultType": {
     "description": "Indicates the type of the result, which allows the client to determine\nhow to parse the result object.\n\nServers implementing this protocol version MUST include this field.\nFor backward compatibility, when a client receives a result from a\nserver implementing an earlier protocol version (which does not include\nresultType), the client MUST treat the absent field as \"complete\".",
     "type": "string"
   }
 }
}

Fields

input_requests: Option<InputRequests>meta: Option<ResultMetaObject>request_state: Option<String>result_type: String

Indicates the type of the result, which allows the client to determine how to parse the result object. Servers implementing this protocol version MUST include this field. For backward compatibility, when a client receives a result from a server implementing an earlier protocol version (which does not include resultType), the client MUST treat the absent field as “complete”.

Implementations

Source

impl InputRequiredResult

pub fn with_request_state<T: Into<String>>(self, request_state: T) -> Self

Sets the opaque requestState returned by the server, so it can correlate the retry with the original request.

pub fn with_input_requests(self, input_requests: InputRequests) -> Self

Sets the inputRequests the server asks the client to resolve before the original request can complete.