InternalError

Struct InternalError 

pub struct InternalError {
    pub code: i64,
    pub data: Option<Value>,
    pub message: String,
}
Latest MCP Protocol 2026_07_28 A JSON-RPC error indicating that an internal error occurred on the receiver. This error is returned when the receiver encounters an unexpected condition that prevents it from fulfilling the request.

JSON schema
{
 "description": "A JSON-RPC error indicating that an internal error occurred on the receiver. This error is returned when the receiver encounters an unexpected condition that prevents it from fulfilling the request.",
 "type": "object",
 "required": [
   "code",
   "message"
 ],
 "properties": {
   "code": {
     "description": "The error type that occurred.",
     "type": "integer",
     "const": -32603
   },
   "data": {
     "description": "Additional information about the error. The value of this member is defined by the sender (e.g. detailed error information, nested errors etc.)."
   },
   "message": {
     "description": "A short description of the error. The message SHOULD be limited to a concise single sentence.",
     "type": "string"
   }
 }
}

Fields

code: i64

The error type that occurred.

data: Option<Value>

Additional information about the error. The value of this member is defined by the sender (e.g. detailed error information, nested errors etc.).

message: String

A short description of the error. The message SHOULD be limited to a concise single sentence.