pub struct ListPromptsResult {
pub cache_scope: ListPromptsResultCacheScope,
pub meta: Option<ResultMetaObject>,
pub next_cursor: Option<String>,
pub prompts: Vec<Prompt>,
pub result_type: String,
pub ttl_ms: u64,
}Expand description
Latest MCP Protocol 2026_07_28 The result returned by the server for a {@link ListPromptsRequestprompts/list} request.
JSON schema
{
"description": "The result returned by the server for a {@link ListPromptsRequestprompts/list} request.",
"type": "object",
"required": [
"cacheScope",
"prompts",
"resultType",
"ttlMs"
],
"properties": {
"_meta": {
"$ref": "#/$defs/ResultMetaObject"
},
"cacheScope": {
"description": "Indicates the intended scope of the cached response, analogous to HTTP\nCache-Control: public vs Cache-Control: private.\n\n- \"public\": The response does not contain user-specific data. Any\n client or intermediary (e.g., shared gateway, caching proxy) MAY cache\n the response and serve it across authorization contexts.\n- \"private\": The response MAY be cached and reused only within the\n same authorization context. Caches MUST NOT be shared across\n authorization contexts (e.g., a different access token requires a\n different cache).",
"type": "string",
"enum": [
"private",
"public"
]
},
"nextCursor": {
"description": "An opaque token representing the pagination position after the last returned result.\nIf present, there may be more results available.",
"type": "string"
},
"prompts": {
"type": "array",
"items": {
"$ref": "#/$defs/Prompt"
}
},
"resultType": {
"description": "Indicates the type of the result, which allows the client to determine\nhow to parse the result object.\n\nServers implementing this protocol version MUST include this field.\nFor backward compatibility, when a client receives a result from a\nserver implementing an earlier protocol version (which does not include\nresultType), the client MUST treat the absent field as \"complete\".",
"type": "string"
},
"ttlMs": {
"description": "A hint from the server indicating how long (in milliseconds) the\nclient MAY cache this response before re-fetching. Semantics are\nanalogous to HTTP Cache-Control max-age.\n\n- If 0, The response SHOULD be considered immediately stale,\n The client MAY re-fetch every time the result is needed.\n- If positive, the client SHOULD consider the result fresh for this many\n milliseconds after receiving the response.",
"type": "integer",
"minimum": 0.0
}
}
}Fields
cache_scope: ListPromptsResultCacheScopeIndicates the intended scope of the cached response, analogous to HTTP Cache-Control: public vs Cache-Control: private. - “public”: The response does not contain user-specific data. Any client or intermediary (e.g., shared gateway, caching proxy) MAY cache the response and serve it across authorization contexts. - “private”: The response MAY be cached and reused only within the same authorization context. Caches MUST NOT be shared across authorization contexts (e.g., a different access token requires a different cache).
meta: Option<ResultMetaObject>next_cursor: Option<String>An opaque token representing the pagination position after the last returned result. If present, there may be more results available.
prompts: Vec<Prompt>result_type: StringIndicates the type of the result, which allows the client to determine how to parse the result object. Servers implementing this protocol version MUST include this field. For backward compatibility, when a client receives a result from a server implementing an earlier protocol version (which does not include resultType), the client MUST treat the absent field as “complete”.
ttl_ms: u64A hint from the server indicating how long (in milliseconds) the client MAY cache this response before re-fetching. Semantics are analogous to HTTP Cache-Control max-age. - If 0, The response SHOULD be considered immediately stale, The client MAY re-fetch every time the result is needed. - If positive, the client SHOULD consider the result fresh for this many milliseconds after receiving the response.