pub struct ListRootsResult {
pub roots: Vec<Root>,
}Expand description
Latest MCP Protocol 2026_07_28 The result returned by the client for a {@link ListRootsRequestroots/list} request. This result contains an array of {@link Root} objects, each representing a root directory or file that the server can operate on.
JSON schema
{
"description": "The result returned by the client for a {@link ListRootsRequestroots/list} request.\nThis result contains an array of {@link Root} objects, each representing a root directory\nor file that the server can operate on.",
"type": "object",
"required": [
"roots"
],
"properties": {
"roots": {
"type": "array",
"items": {
"$ref": "#/$defs/Root"
}
}
}
}Fields
roots: Vec<Root>Trait Implementations
Sourceimpl Clone for ListRootsResult
impl Clone for ListRootsResult
Sourcefn clone(&self) -> ListRootsResult
fn clone(&self) -> ListRootsResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListRootsResult
impl Debug for ListRootsResult
Sourceimpl<'de> Deserialize<'de> for ListRootsResult
impl<'de> Deserialize<'de> for ListRootsResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ListRootsResult> for InputResponse
impl From<ListRootsResult> for InputResponse
Sourcefn from(value: ListRootsResult) -> Self
fn from(value: ListRootsResult) -> Self
Converts to this type from the input type.
Sourceimpl From<ListRootsResult> for ResultFromClient
impl From<ListRootsResult> for ResultFromClient
Sourcefn from(value: ListRootsResult) -> Self
fn from(value: ListRootsResult) -> Self
Converts to this type from the input type.
Sourceimpl From<ListRootsResult> for MessageFromClient
impl From<ListRootsResult> for MessageFromClient
Sourcefn from(value: ListRootsResult) -> Self
fn from(value: ListRootsResult) -> Self
Converts to this type from the input type.
Sourceimpl Serialize for ListRootsResult
impl Serialize for ListRootsResult
Sourceimpl TryFrom<ResultFromClient> for ListRootsResult
impl TryFrom<ResultFromClient> for ListRootsResult