pub struct LoggingMessageNotification {
pub params: LoggingMessageNotificationParams,
/* private fields */
}Expand description
Latest MCP Protocol 2025_11_25 JSONRPCNotification of a log message passed from server to client. If no logging/setLevel request has been sent from the client, the server MAY decide which messages to send automatically.
JSON schema
{
"description": "JSONRPCNotification of a log message passed from server to client. If no logging/setLevel request has been sent from the client, the server MAY decide which messages to send automatically.",
"type": "object",
"required": [
"jsonrpc",
"method",
"params"
],
"properties": {
"jsonrpc": {
"type": "string",
"const": "2.0"
},
"method": {
"type": "string",
"const": "notifications/message"
},
"params": {
"$ref": "#/$defs/LoggingMessageNotificationParams"
}
}
}Fields
params: LoggingMessageNotificationParamsImplementations