MetaObject

Struct MetaObject 

pub struct MetaObject(pub Map<String, Value>);
Latest MCP Protocol 2026_07_28 Represents the contents of a _meta field, which clients and servers use to attach additional metadata to their interactions. Certain key names are reserved by MCP for protocol-level metadata; implementations MUST NOT make assumptions about values at these keys. Additionally, specific schema definitions may reserve particular names for purpose-specific metadata, as declared in those definitions. Valid keys have two segments: Prefix:

  • Optional — if specified, MUST be a series of labels separated by dots (.), followed by a slash (/).
  • Labels MUST start with a letter and end with a letter or digit. Interior characters may be letters, digits, or hyphens (-).
  • Implementations SHOULD use reverse DNS notation (e.g., com.example/ rather than example.com/).
  • Any prefix where the second label is modelcontextprotocol or mcp is reserved for MCP use. For example: io.modelcontextprotocol/, dev.mcp/, org.modelcontextprotocol.api/, and com.mcp.tools/ are all reserved. However, com.example.mcp/ is NOT reserved, as the second label is example. Name:
  • Unless empty, MUST start and end with an alphanumeric character ([a-z0-9A-Z]).
  • Interior characters may be alphanumeric, hyphens (-), underscores (_), or dots (.).
JSON schema
{
 "description": "Represents the contents of a _meta field, which clients and servers use to attach additional metadata to their interactions.\n\nCertain key names are reserved by MCP for protocol-level metadata; implementations MUST NOT make assumptions about values at these keys. Additionally, specific schema definitions may reserve particular names for purpose-specific metadata, as declared in those definitions.\n\nValid keys have two segments:\n\n**Prefix:**\n- Optional — if specified, MUST be a series of _labels_ separated by dots (.), followed by a slash (/).\n- Labels MUST start with a letter and end with a letter or digit. Interior characters may be letters, digits, or hyphens (-).\n- Implementations SHOULD use reverse DNS notation (e.g., com.example/ rather than example.com/).\n- Any prefix where the second label is modelcontextprotocol or mcp is **reserved** for MCP use. For example: io.modelcontextprotocol/, dev.mcp/, org.modelcontextprotocol.api/, and com.mcp.tools/ are all reserved. However, com.example.mcp/ is NOT reserved, as the second label is example.\n\n**Name:**\n- Unless empty, MUST start and end with an alphanumeric character ([a-z0-9A-Z]).\n- Interior characters may be alphanumeric, hyphens (-), underscores (_), or dots (.).",
 "type": "object",
 "additionalProperties": {}
}

Tuple Fields

0: Map<String, Value>