pub struct NotificationMetaObject {
pub io_modelcontextprotocol_subscription_id: Option<RequestId>,
pub extra: Option<Map<String, Value>>,
}Expand description
Latest MCP Protocol 2026_07_28 Extends {@link MetaObject} with additional notification-specific fields. All key naming rules from MetaObject apply.
JSON schema
{
"description": "Extends {@link MetaObject} with additional notification-specific fields. All key naming rules from MetaObject apply.",
"type": "object",
"properties": {
"io.modelcontextprotocol/subscriptionId": {
"description": "Identifies the subscription stream a notification was delivered on. The\nserver MUST include this key on every notification delivered via a\n{@link SubscriptionsListenRequestsubscriptions/listen} stream, so the\nclient can correlate the notification with the originating subscription.\nThe key is absent on notifications not delivered via a subscription\nstream (e.g. progress notifications for an in-flight request), which is\nwhy it is optional here.\n\nThe value is the JSON-RPC ID of the subscriptions/listen request that\nopened the stream.",
"$ref": "#/$defs/RequestId"
}
},
"additionalProperties": {}
}Fields
io_modelcontextprotocol_subscription_id: Option<RequestId>Identifies the subscription stream a notification was delivered on. The server MUST include this key on every notification delivered via a {@link SubscriptionsListenRequestsubscriptions/listen} stream, so the client can correlate the notification with the originating subscription. The key is absent on notifications not delivered via a subscription stream (e.g. progress notifications for an in-flight request), which is why it is optional here. The value is the JSON-RPC ID of the subscriptions/listen request that opened the stream.
extra: Option<Map<String, Value>>Trait Implementations
Sourceimpl Clone for NotificationMetaObject
impl Clone for NotificationMetaObject
Sourcefn clone(&self) -> NotificationMetaObject
fn clone(&self) -> NotificationMetaObject
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NotificationMetaObject
impl Debug for NotificationMetaObject
Sourceimpl Default for NotificationMetaObject
impl Default for NotificationMetaObject
Sourcefn default() -> NotificationMetaObject
fn default() -> NotificationMetaObject
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for NotificationMetaObject
impl<'de> Deserialize<'de> for NotificationMetaObject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more