PaginatedResult

Struct PaginatedResult 

pub struct PaginatedResult {
    pub meta: Option<ResultMetaObject>,
    pub next_cursor: Option<String>,
    pub result_type: String,
}
Latest MCP Protocol 2026_07_28 PaginatedResult

JSON schema
{
 "type": "object",
 "required": [
   "resultType"
 ],
 "properties": {
   "_meta": {
     "$ref": "#/$defs/ResultMetaObject"
   },
   "nextCursor": {
     "description": "An opaque token representing the pagination position after the last returned result.\nIf present, there may be more results available.",
     "type": "string"
   },
   "resultType": {
     "description": "Indicates the type of the result, which allows the client to determine\nhow to parse the result object.\n\nServers implementing this protocol version MUST include this field.\nFor backward compatibility, when a client receives a result from a\nserver implementing an earlier protocol version (which does not include\nresultType), the client MUST treat the absent field as \"complete\".",
     "type": "string"
   }
 }
}

Fields

meta: Option<ResultMetaObject>next_cursor: Option<String>

An opaque token representing the pagination position after the last returned result. If present, there may be more results available.

result_type: String

Indicates the type of the result, which allows the client to determine how to parse the result object. Servers implementing this protocol version MUST include this field. For backward compatibility, when a client receives a result from a server implementing an earlier protocol version (which does not include resultType), the client MUST treat the absent field as “complete”.