pub struct ReadResourceRequestParams {
pub input_responses: Option<InputResponses>,
pub meta: RequestMetaObject,
pub request_state: Option<String>,
pub uri: String,
}Expand description
Latest MCP Protocol 2026_07_28 Parameters for a resources/read request.
JSON schema
{
"description": "Parameters for a resources/read request.",
"type": "object",
"required": [
"_meta",
"uri"
],
"properties": {
"_meta": {
"$ref": "#/$defs/RequestMetaObject"
},
"inputResponses": {
"$ref": "#/$defs/InputResponses"
},
"requestState": {
"type": "string"
},
"uri": {
"description": "The URI of the resource. The URI can use any protocol; it is up to the server how to interpret it.",
"type": "string",
"format": "uri"
}
}
}Fields
input_responses: Option<InputResponses>meta: RequestMetaObjectrequest_state: Option<String>uri: StringThe URI of the resource. The URI can use any protocol; it is up to the server how to interpret it.
Implementations
Sourceimpl ReadResourceRequestParams
impl ReadResourceRequestParams
Sourcepub fn with_input_responses(self, input_responses: InputResponses) -> Self
pub fn with_input_responses(self, input_responses: InputResponses) -> Self
Sets the resolved inputResponses for retrying this request after an
input_required result.
Sourcepub fn with_request_state<T: Into<String>>(self, request_state: T) -> Self
pub fn with_request_state<T: Into<String>>(self, request_state: T) -> Self
Sets the opaque requestState returned by the server, so it can
correlate the retry with the original request.