pub struct ReadResourceResultResponse {
pub id: RequestId,
pub result: ReadResourceResultResponseResult,
/* private fields */
}Expand description
Latest MCP Protocol 2026_07_28 A successful response from the server for a {@link ReadResourceRequestresources/read} request.
JSON schema
{
"description": "A successful response from the server for a {@link ReadResourceRequestresources/read} request.",
"type": "object",
"required": [
"id",
"jsonrpc",
"result"
],
"properties": {
"id": {
"$ref": "#/$defs/RequestId"
},
"jsonrpc": {
"type": "string",
"const": "2.0"
},
"result": {
"anyOf": [
{
"$ref": "#/$defs/InputRequiredResult"
},
{
"$ref": "#/$defs/ReadResourceResult"
}
]
}
}
}Fields
id: RequestIdresult: ReadResourceResultResponseResultImplementations