pub struct ResultMetaObject {
pub io_modelcontextprotocol_server_info: Option<Implementation>,
pub extra: Option<Map<String, Value>>,
}Expand description
Latest MCP Protocol 2026_07_28 Extends {@link MetaObject} with additional result-specific fields. All key naming rules from MetaObject apply.
JSON schema
{
"description": "Extends {@link MetaObject} with additional result-specific fields. All key naming rules from MetaObject apply.",
"type": "object",
"properties": {
"io.modelcontextprotocol/serverInfo": {
"description": "Identifies the server software producing the response. Servers SHOULD\ninclude this field on every response unless specifically configured not\nto do so.\n\nThe {@link Implementation} schema requires name and version; other\nfields are optional.\n\nThe value is self-reported by the server and is not verified by the\nprotocol. It is intended for display, logging, and debugging. Clients\nSHOULD NOT use it to change their behavior, and SHOULD NOT rely on it for\nsecurity decisions.",
"$ref": "#/$defs/Implementation"
}
},
"additionalProperties": {}
}Fields
io_modelcontextprotocol_server_info: Option<Implementation>Identifies the server software producing the response. Servers SHOULD include this field on every response unless specifically configured not to do so. The {@link Implementation} schema requires name and version; other fields are optional. The value is self-reported by the server and is not verified by the protocol. It is intended for display, logging, and debugging. Clients SHOULD NOT use it to change their behavior, and SHOULD NOT rely on it for security decisions.
extra: Option<Map<String, Value>>Trait Implementations
Sourceimpl Clone for ResultMetaObject
impl Clone for ResultMetaObject
Sourcefn clone(&self) -> ResultMetaObject
fn clone(&self) -> ResultMetaObject
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResultMetaObject
impl Debug for ResultMetaObject
Sourceimpl Default for ResultMetaObject
impl Default for ResultMetaObject
Sourcefn default() -> ResultMetaObject
fn default() -> ResultMetaObject
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ResultMetaObject
impl<'de> Deserialize<'de> for ResultMetaObject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more