pub struct ResultType(pub String);Expand description
Latest MCP Protocol 2026_07_28 Indicates the type of a {@link Result} object, allowing the client to determine how to parse the response. complete - the request completed successfully and the result contains the final content. input_required - the request requires additional input and the result contains an {@link InputRequiredResult} object with instructions for the client to provide additional input before retrying the original request.
JSON schema
{
"description": "Indicates the type of a {@link Result} object, allowing the client to\ndetermine how to parse the response.\n\ncomplete - the request completed successfully and the result contains the final content.\ninput_required - the request requires additional input and the result contains an {@link InputRequiredResult} object with instructions for the client to provide additional input before retrying the original request.",
"type": "string"
}Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for ResultType
impl Clone for ResultType
Sourcefn clone(&self) -> ResultType
fn clone(&self) -> ResultType
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResultType
impl Debug for ResultType
Sourceimpl<'de> Deserialize<'de> for ResultType
impl<'de> Deserialize<'de> for ResultType
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ResultType
Sourceimpl Hash for ResultType
impl Hash for ResultType
Sourceimpl Ord for ResultType
impl Ord for ResultType
Sourcefn cmp(&self, other: &ResultType) -> Ordering
fn cmp(&self, other: &ResultType) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ResultType
impl PartialEq for ResultType
Sourceimpl PartialOrd for ResultType
impl PartialOrd for ResultType
Sourceimpl Serialize for ResultType
impl Serialize for ResultType
impl StructuralPartialEq for ResultType