pub struct SubscriptionFilter {
pub prompts_list_changed: Option<bool>,
pub resource_subscriptions: Vec<String>,
pub resources_list_changed: Option<bool>,
pub tools_list_changed: Option<bool>,
}Expand description
Latest MCP Protocol 2026_07_28 The set of notification types a client may opt in to on a {@link SubscriptionsListenRequestsubscriptions/listen} request. Each notification type is opt-in; the server MUST NOT send notification types the client has not explicitly requested here.
JSON schema
{
"description": "The set of notification types a client may opt in to on a\n{@link SubscriptionsListenRequestsubscriptions/listen} request.\n\nEach notification type is **opt-in**; the server **MUST NOT** send\nnotification types the client has not explicitly requested here.",
"type": "object",
"properties": {
"promptsListChanged": {
"description": "If true, receive {@link PromptListChangedNotificationnotifications/prompts/list_changed}.",
"type": "boolean"
},
"resourceSubscriptions": {
"description": "Subscribe to {@link ResourceUpdatedNotificationnotifications/resources/updated} for these resource URIs.\nReplaces the former resources/subscribe RPC.",
"type": "array",
"items": {
"type": "string"
}
},
"resourcesListChanged": {
"description": "If true, receive {@link ResourceListChangedNotificationnotifications/resources/list_changed}.",
"type": "boolean"
},
"toolsListChanged": {
"description": "If true, receive {@link ToolListChangedNotificationnotifications/tools/list_changed}.",
"type": "boolean"
}
}
}Fields
prompts_list_changed: Option<bool>If true, receive {@link PromptListChangedNotificationnotifications/prompts/list_changed}.
resource_subscriptions: Vec<String>Subscribe to {@link ResourceUpdatedNotificationnotifications/resources/updated} for these resource URIs. Replaces the former resources/subscribe RPC.
resources_list_changed: Option<bool>If true, receive {@link ResourceListChangedNotificationnotifications/resources/list_changed}.
tools_list_changed: Option<bool>If true, receive {@link ToolListChangedNotificationnotifications/tools/list_changed}.