pub struct SubscriptionsAcknowledgedNotificationParams {
pub meta: Option<NotificationMetaObject>,
pub notifications: SubscriptionFilter,
}Expand description
Latest MCP Protocol 2026_07_28 Parameters for a {@link SubscriptionsAcknowledgedNotificationnotifications/subscriptions/acknowledged} notification.
JSON schema
{
"description": "Parameters for a {@link SubscriptionsAcknowledgedNotificationnotifications/subscriptions/acknowledged} notification.",
"type": "object",
"required": [
"notifications"
],
"properties": {
"_meta": {
"$ref": "#/$defs/NotificationMetaObject"
},
"notifications": {
"description": "The subset of requested notification types the server agreed to honor.\nOnly includes notification types the server actually supports; if the\nclient requested an unsupported type (e.g., promptsListChanged when\nthe server has no prompts), it is omitted from this set.",
"$ref": "#/$defs/SubscriptionFilter"
}
}
}Fields
meta: Option<NotificationMetaObject>notifications: SubscriptionFilterThe subset of requested notification types the server agreed to honor. Only includes notification types the server actually supports; if the client requested an unsupported type (e.g., promptsListChanged when the server has no prompts), it is omitted from this set.