pub struct ToolOutputSchema {
pub schema: Option<String>,
pub extra: Option<Map<String, Value>>,
}Expand description
Latest MCP Protocol 2026_07_28 An optional JSON Schema object defining the structure of the tool’s output returned in the structuredContent field of a {@link CallToolResult}. This can be any valid JSON Schema 2020-12. Defaults to JSON Schema 2020-12 when no explicit $schema is provided.
JSON schema
{
"description": "An optional JSON Schema object defining the structure of the tool's output returned in\nthe structuredContent field of a {@link CallToolResult}. This can be any valid JSON Schema 2020-12.\n\nDefaults to JSON Schema 2020-12 when no explicit $schema is provided.",
"type": "object",
"properties": {
"$schema": {
"type": "string"
}
},
"additionalProperties": {}
}Fields
schema: Option<String>extra: Option<Map<String, Value>>Trait Implementations
Sourceimpl Clone for ToolOutputSchema
impl Clone for ToolOutputSchema
Sourcefn clone(&self) -> ToolOutputSchema
fn clone(&self) -> ToolOutputSchema
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ToolOutputSchema
impl Debug for ToolOutputSchema
Sourceimpl Default for ToolOutputSchema
impl Default for ToolOutputSchema
Sourcefn default() -> ToolOutputSchema
fn default() -> ToolOutputSchema
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ToolOutputSchema
impl<'de> Deserialize<'de> for ToolOutputSchema
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more