pub struct UnsupportedProtocolVersionErrorErrorData {
pub requested: String,
pub supported: Vec<String>,
}Expand description
Latest MCP Protocol 2026_07_28 UnsupportedProtocolVersionErrorErrorData
JSON schema
{
"type": "object",
"required": [
"requested",
"supported"
],
"properties": {
"requested": {
"description": "The protocol version that was requested by the client.",
"type": "string"
},
"supported": {
"description": "Protocol versions the server supports. The client should choose a\nmutually supported version from this list and retry.",
"type": "array",
"items": {
"type": "string"
}
}
}
}Fields
requested: StringThe protocol version that was requested by the client.
supported: Vec<String>Protocol versions the server supports. The client should choose a mutually supported version from this list and retry.