GenericResult

Type Alias GenericResult 

pub type GenericResult = Result;
Latest MCP Protocol 2026_07_28 Alias to avoid conflicts with Rust’s standard Result type.

Aliased Type

pub struct GenericResult {
    pub meta: Option<ResultMetaObject>,
    pub result_type: String,
    pub extra: Option<Map<String, Value>>,
}

Fields

meta: Option<ResultMetaObject>result_type: String

Indicates the type of the result, which allows the client to determine how to parse the result object. Servers implementing this protocol version MUST include this field. For backward compatibility, when a client receives a result from a server implementing an earlier protocol version (which does not include resultType), the client MUST treat the absent field as “complete”.

extra: Option<Map<String, Value>>