Crate rust_mcp_schema

Crate rust_mcp_schema 

Modules

mcp_2025_11_25
schema_utils
Latest MCP Protocol 2025_11_25

Structs

Annotations
Latest MCP Protocol 2025_11_25 Optional annotations for the client. The client can use annotations to inform how objects are used or displayed
AudioContent
Latest MCP Protocol 2025_11_25 Audio provided to or from an LLM.
BaseMetadata
Latest MCP Protocol 2025_11_25 Base interface for metadata with name (identifier) and title (display name) properties.
BlobResourceContents
Latest MCP Protocol 2025_11_25 BlobResourceContents
BooleanSchema
Latest MCP Protocol 2025_11_25 BooleanSchema
CallToolMeta
Latest MCP Protocol 2025_11_25 See General fields: _meta for notes on _meta usage.
CallToolRequest
Latest MCP Protocol 2025_11_25 Used by the client to invoke a tool provided by the server.
CallToolRequestParams
Latest MCP Protocol 2025_11_25 Parameters for a tools/call request.
CallToolResult
Latest MCP Protocol 2025_11_25 The server’s response to a tool call.
CancelTaskParams
Latest MCP Protocol 2025_11_25 CancelTaskParams
CancelTaskRequest
Latest MCP Protocol 2025_11_25 A request to cancel a task.
CancelTaskResult
Latest MCP Protocol 2025_11_25 The response to a tasks/cancel request.
CancelledNotification
Latest MCP Protocol 2025_11_25 This notification can be sent by either side to indicate that it is cancelling a previously-issued request. The request SHOULD still be in-flight, but due to communication latency, it is always possible that this notification MAY arrive after the request has already finished. This notification indicates that the result will be unused, so any associated processing SHOULD cease. A client MUST NOT attempt to cancel its initialize request. For task cancellation, use the tasks/cancel request instead of this notification.
CancelledNotificationParams
Latest MCP Protocol 2025_11_25 Parameters for a notifications/cancelled notification.
ClientCapabilities
Latest MCP Protocol 2025_11_25 Capabilities a client may support. Known capabilities are defined here, in this schema, but this is not a closed set: any client can define its own, additional capabilities.
ClientElicitation
Latest MCP Protocol 2025_11_25 Present if the client supports elicitation from the server.
ClientRoots
Latest MCP Protocol 2025_11_25 Present if the client supports listing roots.
ClientSampling
Latest MCP Protocol 2025_11_25 Present if the client supports sampling from an LLM.
ClientTaskElicitation
Latest MCP Protocol 2025_11_25 Task support for elicitation-related requests.
ClientTaskRequest
Latest MCP Protocol 2025_11_25 Specifies which request types can be augmented with tasks.
ClientTaskSampling
Latest MCP Protocol 2025_11_25 Task support for sampling-related requests.
ClientTasks
Latest MCP Protocol 2025_11_25 Present if the client supports task-augmented requests.
CompleteRequest
Latest MCP Protocol 2025_11_25 A request from the client to the server, to ask for completion options.
CompleteRequestArgument
Latest MCP Protocol 2025_11_25 The argument’s information
CompleteRequestContext
Latest MCP Protocol 2025_11_25 Additional, optional context for completions
CompleteRequestMeta
Latest MCP Protocol 2025_11_25 See General fields: _meta for notes on _meta usage.
CompleteRequestParams
Latest MCP Protocol 2025_11_25 Parameters for a completion/complete request.
CompleteResult
Latest MCP Protocol 2025_11_25 The server’s response to a completion/complete request
CompleteResultCompletion
Latest MCP Protocol 2025_11_25 CompleteResultCompletion
CreateMessageRequest
Latest MCP Protocol 2025_11_25 A request from the server to sample an LLM via the client. The client has full discretion over which model to select. The client should also inform the user before beginning sampling, to allow them to inspect the request (human in the loop) and decide whether to approve it.
CreateMessageRequestParams
Latest MCP Protocol 2025_11_25 Parameters for a sampling/createMessage request.
CreateMessageResult
Latest MCP Protocol 2025_11_25 The client’s response to a sampling/createMessage request from the server. The client should inform the user before returning the sampled message, to allow them to inspect the response (human in the loop) and decide whether to allow the server to see it.
CreateTaskResult
Latest MCP Protocol 2025_11_25 A response to a task-augmented request.
Cursor
Latest MCP Protocol 2025_11_25 An opaque token used to represent a cursor for pagination.
ElicitCompleteParams
Latest MCP Protocol 2025_11_25 ElicitCompleteParams
ElicitFormMeta
Latest MCP Protocol 2025_11_25 See General fields: _meta for notes on _meta usage.
ElicitFormSchema
Latest MCP Protocol 2025_11_25 A restricted subset of JSON Schema. Only top-level properties are allowed, without nesting.
ElicitRequest
Latest MCP Protocol 2025_11_25 A request from the server to elicit additional information from the user via the client.
ElicitRequestFormParams
Latest MCP Protocol 2025_11_25 The parameters for a request to elicit non-sensitive information from the user via a form in the client.
ElicitRequestUrlParams
Latest MCP Protocol 2025_11_25 The parameters for a request to elicit information from the user via a URL in the client.
ElicitResult
Latest MCP Protocol 2025_11_25 The client’s response to an elicitation request.
ElicitUrlMeta
Latest MCP Protocol 2025_11_25 See General fields: _meta for notes on _meta usage.
ElicitationCompleteNotification
Latest MCP Protocol 2025_11_25 An optional notification from the server to the client, informing it of a completion of a out-of-band elicitation request.
EmbeddedResource
Latest MCP Protocol 2025_11_25 The contents of a resource, embedded into a prompt or tool call result. It is up to the client how best to render embedded resources for the benefit of the LLM and/or the user.
EmptyResult
Latest MCP Protocol 2025_11_25 EmptyResult
GetPromptMeta
Latest MCP Protocol 2025_11_25 See General fields: _meta for notes on _meta usage.
GetPromptRequest
Latest MCP Protocol 2025_11_25 Used by the client to get a prompt provided by the server.
GetPromptRequestParams
Latest MCP Protocol 2025_11_25 Parameters for a prompts/get request.
GetPromptResult
Latest MCP Protocol 2025_11_25 The server’s response to a prompts/get request from the client.
GetTaskParams
Latest MCP Protocol 2025_11_25 GetTaskParams
GetTaskPayloadParams
Latest MCP Protocol 2025_11_25 GetTaskPayloadParams
GetTaskPayloadRequest
Latest MCP Protocol 2025_11_25 A request to retrieve the result of a completed task.
GetTaskPayloadResult
Latest MCP Protocol 2025_11_25 The response to a tasks/result request. The structure matches the result type of the original request. For example, a tools/call task would return the CallToolResult structure.
GetTaskRequest
Latest MCP Protocol 2025_11_25 A request to retrieve the state of a task.
GetTaskResult
Latest MCP Protocol 2025_11_25 The response to a tasks/get request.
Icon
Latest MCP Protocol 2025_11_25 An optionally-sized icon that can be displayed in a user interface.
Icons
Latest MCP Protocol 2025_11_25 Base interface to add icons property.
ImageContent
Latest MCP Protocol 2025_11_25 An image provided to or from an LLM.
Implementation
Latest MCP Protocol 2025_11_25 Describes the MCP implementation.
InitializeMeta
Latest MCP Protocol 2025_11_25 See General fields: _meta for notes on _meta usage.
InitializeRequest
Latest MCP Protocol 2025_11_25 This request is sent from the client to the server when it first connects, asking it to begin initialization.
InitializeRequestParams
Latest MCP Protocol 2025_11_25 Parameters for an initialize request.
InitializeResult
Latest MCP Protocol 2025_11_25 After receiving an initialize request from the client, the server sends this response.
InitializedNotification
Latest MCP Protocol 2025_11_25 This notification is sent from the client to the server after initialization has finished.
JsonrpcErrorResponse
Latest MCP Protocol 2025_11_25 A response to a request that indicates an error occurred.
JsonrpcNotification
Latest MCP Protocol 2025_11_25 A notification which does not expect a response.
JsonrpcRequest
Latest MCP Protocol 2025_11_25 A request that expects a response.
JsonrpcResultResponse
Latest MCP Protocol 2025_11_25 A successful (non-error) response to a request.
LegacyTitledEnumSchema
Latest MCP Protocol 2025_11_25 Use TitledSingleSelectEnumSchema instead. This interface will be removed in a future version.
ListPromptsRequest
Latest MCP Protocol 2025_11_25 Sent from the client to request a list of prompts and prompt templates the server has.
ListPromptsResult
Latest MCP Protocol 2025_11_25 The server’s response to a prompts/list request from the client.
ListResourceTemplatesRequest
Latest MCP Protocol 2025_11_25 Sent from the client to request a list of resource templates the server has.
ListResourceTemplatesResult
Latest MCP Protocol 2025_11_25 The server’s response to a resources/templates/list request from the client.
ListResourcesRequest
Latest MCP Protocol 2025_11_25 Sent from the client to request a list of resources the server has.
ListResourcesResult
Latest MCP Protocol 2025_11_25 The server’s response to a resources/list request from the client.
ListRootsRequest
Latest MCP Protocol 2025_11_25 Sent from the server to request a list of root URIs from the client. Roots allow servers to ask for specific directories or files to operate on. A common example for roots is providing a set of repositories or directories a server should operate on. This request is typically used when the server needs to understand the file system structure or access specific locations that the client has permission to read from.
ListRootsResult
Latest MCP Protocol 2025_11_25 The client’s response to a roots/list request from the server. This result contains an array of Root objects, each representing a root directory or file that the server can operate on.
ListTasksRequest
Latest MCP Protocol 2025_11_25 A request to retrieve a list of tasks.
ListTasksResult
Latest MCP Protocol 2025_11_25 The response to a tasks/list request.
ListToolsRequest
Latest MCP Protocol 2025_11_25 Sent from the client to request a list of tools the server has.
ListToolsResult
Latest MCP Protocol 2025_11_25 The server’s response to a tools/list request from the client.
LoggingMessageNotification
Latest MCP Protocol 2025_11_25 JSONRPCNotification of a log message passed from server to client. If no logging/setLevel request has been sent from the client, the server MAY decide which messages to send automatically.
LoggingMessageNotificationParams
Latest MCP Protocol 2025_11_25 Parameters for a notifications/message notification.
MessageMeta
Latest MCP Protocol 2025_11_25 See General fields: _meta for notes on _meta usage.
ModelHint
Latest MCP Protocol 2025_11_25 Hints to use for model selection. Keys not declared here are currently left unspecified by the spec and are up to the client to interpret.
ModelPreferences
Latest MCP Protocol 2025_11_25 The server’s preferences for model selection, requested of the client during sampling. Because LLMs can vary along multiple dimensions, choosing the “best” model is rarely straightforward. Different models excel in different areas—some are faster but less capable, others are more capable but more expensive, and so on. This interface allows servers to express their priorities across multiple dimensions to help clients make an appropriate selection for their use case. These preferences are always advisory. The client MAY ignore them. It is also up to the client to decide how to interpret these preferences and how to balance them against other considerations.
Notification
Latest MCP Protocol 2025_11_25 Notification
NotificationParams
Latest MCP Protocol 2025_11_25 NotificationParams
NumberSchema
Latest MCP Protocol 2025_11_25 NumberSchema
PaginatedMeta
Latest MCP Protocol 2025_11_25 See General fields: _meta for notes on _meta usage.
PaginatedRequest
Latest MCP Protocol 2025_11_25 PaginatedRequest
PaginatedRequestParams
Latest MCP Protocol 2025_11_25 Common parameters for paginated requests.
PaginatedResult
Latest MCP Protocol 2025_11_25 PaginatedResult
ParseProtocolVersionError
PingRequest
Latest MCP Protocol 2025_11_25 A ping, issued by either the server or the client, to check that the other party is still alive. The receiver must promptly respond, or else may be disconnected.
ProgressNotification
Latest MCP Protocol 2025_11_25 An out-of-band notification used to inform the receiver of a progress update for a long-running request.
ProgressNotificationParams
Latest MCP Protocol 2025_11_25 Parameters for a notifications/progress notification.
Prompt
Latest MCP Protocol 2025_11_25 A prompt or prompt template that the server offers.
PromptArgument
Latest MCP Protocol 2025_11_25 Describes an argument that a prompt can accept.
PromptListChangedNotification
Latest MCP Protocol 2025_11_25 An optional notification from the server to the client, informing it that the list of prompts it offers has changed. This may be issued by servers without any previous subscription from the client.
PromptMessage
Latest MCP Protocol 2025_11_25 Describes a message returned as part of a prompt. This is similar to SamplingMessage, but also supports the embedding of resources from the MCP server.
PromptReference
Latest MCP Protocol 2025_11_25 Identifies a prompt.
ReadResourceMeta
Latest MCP Protocol 2025_11_25 See General fields: _meta for notes on _meta usage.
ReadResourceRequest
Latest MCP Protocol 2025_11_25 Sent from the client to the server, to read a specific resource URI.
ReadResourceRequestParams
Latest MCP Protocol 2025_11_25 Parameters for a resources/read request.
ReadResourceResult
Latest MCP Protocol 2025_11_25 The server’s response to a resources/read request from the client.
RelatedTaskMetadata
Latest MCP Protocol 2025_11_25 Metadata for associating messages with a task. Include this in the _meta field under the key io.modelcontextprotocol/related-task.
Request
Latest MCP Protocol 2025_11_25 Request
RequestParams
Latest MCP Protocol 2025_11_25 Common params for any request.
RequestParamsMeta
Latest MCP Protocol 2025_11_25 See General fields: _meta for notes on _meta usage.
Resource
Latest MCP Protocol 2025_11_25 A known resource that the server is capable of reading.
ResourceContents
Latest MCP Protocol 2025_11_25 The contents of a specific resource or sub-resource.
ResourceLink
Latest MCP Protocol 2025_11_25 A resource that the server is capable of reading, included in a prompt or tool call result. Note: resource links returned by tools are not guaranteed to appear in the results of resources/list requests.
ResourceListChangedNotification
Latest MCP Protocol 2025_11_25 An optional notification from the server to the client, informing it that the list of resources it can read from has changed. This may be issued by servers without any previous subscription from the client.
ResourceMeta
Latest MCP Protocol 2025_11_25 See General fields: _meta for notes on _meta usage.
ResourceRequestParams
Latest MCP Protocol 2025_11_25 Common parameters when working with resources.
ResourceTemplate
Latest MCP Protocol 2025_11_25 A template description for resources available on the server.
ResourceTemplateReference
Latest MCP Protocol 2025_11_25 A reference to a resource or resource template definition.
ResourceUpdatedNotification
Latest MCP Protocol 2025_11_25 A notification from the server to the client, informing it that a resource has changed and may need to be read again. This should only be sent if the client previously sent a resources/subscribe request.
ResourceUpdatedNotificationParams
Latest MCP Protocol 2025_11_25 Parameters for a notifications/resources/updated notification.
Result
Latest MCP Protocol 2025_11_25 Result
Root
Latest MCP Protocol 2025_11_25 Represents a root directory or file that the server can operate on.
RootsListChangedNotification
Latest MCP Protocol 2025_11_25 A notification from the client to the server, informing it that the list of roots has changed. This notification should be sent whenever the client adds, removes, or modifies any root. The server should then request an updated list of roots using the ListRootsRequest.
RpcError
Latest MCP Protocol 2025_11_25 RpcError
SamplingMessage
Latest MCP Protocol 2025_11_25 Describes a message issued to or received from an LLM API.
ServerCapabilities
Latest MCP Protocol 2025_11_25 Capabilities that a server may support. Known capabilities are defined here, in this schema, but this is not a closed set: any server can define its own, additional capabilities.
ServerCapabilitiesPrompts
Latest MCP Protocol 2025_11_25 Present if the server offers any prompt templates.
ServerCapabilitiesResources
Latest MCP Protocol 2025_11_25 Present if the server offers any resources to read.
ServerCapabilitiesTools
Latest MCP Protocol 2025_11_25 Present if the server offers any tools to call.
ServerTaskRequest
Latest MCP Protocol 2025_11_25 Specifies which request types can be augmented with tasks.
ServerTaskTools
Latest MCP Protocol 2025_11_25 Task support for tool-related requests.
ServerTasks
Latest MCP Protocol 2025_11_25 Present if the server supports task-augmented requests.
SetLevelMeta
Latest MCP Protocol 2025_11_25 See General fields: _meta for notes on _meta usage.
SetLevelRequest
Latest MCP Protocol 2025_11_25 A request from the client to the server, to enable or adjust logging.
SetLevelRequestParams
Latest MCP Protocol 2025_11_25 Parameters for a logging/setLevel request.
StringSchema
Latest MCP Protocol 2025_11_25 StringSchema
SubscribeMeta
Latest MCP Protocol 2025_11_25 See General fields: _meta for notes on _meta usage.
SubscribeRequest
Latest MCP Protocol 2025_11_25 Sent from the client to request resources/updated notifications from the server whenever a particular resource changes.
SubscribeRequestParams
Latest MCP Protocol 2025_11_25 Parameters for a resources/subscribe request.
Task
Latest MCP Protocol 2025_11_25 Data associated with a task.
TaskAugmentedMeta
Latest MCP Protocol 2025_11_25 See General fields: _meta for notes on _meta usage.
TaskAugmentedRequestParams
Latest MCP Protocol 2025_11_25 Common params for any task-augmented request.
TaskMetadata
Latest MCP Protocol 2025_11_25 Metadata for augmenting a request with task execution. Include this in the task field of the request parameters.
TaskStatusNotification
Latest MCP Protocol 2025_11_25 An optional notification from the receiver to the requestor, informing them that a task’s status has changed. Receivers are not required to send these notifications.
TaskStatusNotificationParams
Latest MCP Protocol 2025_11_25 Parameters for a notifications/tasks/status notification.
TextContent
Latest MCP Protocol 2025_11_25 Text provided to or from an LLM.
TextResourceContents
Latest MCP Protocol 2025_11_25 TextResourceContents
TitledMultiSelectEnumSchema
Latest MCP Protocol 2025_11_25 Schema for multiple-selection enumeration with display titles for each option.
TitledMultiSelectEnumSchemaItems
Latest MCP Protocol 2025_11_25 Schema for array items with enum options and display labels.
TitledMultiSelectEnumSchemaItemsAnyOfItem
Latest MCP Protocol 2025_11_25 TitledMultiSelectEnumSchemaItemsAnyOfItem
TitledSingleSelectEnumSchema
Latest MCP Protocol 2025_11_25 Schema for single-selection enumeration with display titles for each option.
TitledSingleSelectEnumSchemaOneOfItem
Latest MCP Protocol 2025_11_25 TitledSingleSelectEnumSchemaOneOfItem
Tool
Latest MCP Protocol 2025_11_25 Definition for a tool the client can call.
ToolAnnotations
Latest MCP Protocol 2025_11_25 Additional properties describing a Tool to clients. NOTE: all properties in ToolAnnotations are hints. They are not guaranteed to provide a faithful description of tool behavior (including descriptive properties like title). Clients should never make tool use decisions based on ToolAnnotations received from untrusted servers.
ToolChoice
Latest MCP Protocol 2025_11_25 Controls tool selection behavior for sampling requests.
ToolExecution
Latest MCP Protocol 2025_11_25 Execution-related properties for a tool.
ToolInputSchema
Latest MCP Protocol 2025_11_25 A JSON Schema object defining the expected parameters for the tool.
ToolListChangedNotification
Latest MCP Protocol 2025_11_25 An optional notification from the server to the client, informing it that the list of tools it offers has changed. This may be issued by servers without any previous subscription from the client.
ToolOutputSchema
Latest MCP Protocol 2025_11_25 An optional JSON Schema object defining the structure of the tool’s output returned in the structuredContent field of a CallToolResult. Defaults to JSON Schema 2020-12 when no explicit $schema is provided. Currently restricted to type: “object” at the root level.
ToolResultContent
Latest MCP Protocol 2025_11_25 The result of a tool use, provided by the user back to the assistant.
ToolUseContent
Latest MCP Protocol 2025_11_25 A request from the assistant to call a tool.
UnsubscribeMeta
Latest MCP Protocol 2025_11_25 See General fields: _meta for notes on _meta usage.
UnsubscribeRequest
Latest MCP Protocol 2025_11_25 Sent from the client to request cancellation of resources/updated notifications from the server. This should follow a previous resources/subscribe request.
UnsubscribeRequestParams
Latest MCP Protocol 2025_11_25 Parameters for a resources/unsubscribe request.
UntitledMultiSelectEnumSchema
Latest MCP Protocol 2025_11_25 Schema for multiple-selection enumeration without display titles for options.
UntitledMultiSelectEnumSchemaItems
Latest MCP Protocol 2025_11_25 Schema for the array items.
UntitledSingleSelectEnumSchema
Latest MCP Protocol 2025_11_25 Schema for single-selection enumeration without display titles for options.
UrlElicitError
Latest MCP Protocol 2025_11_25 UrlElicitError
UrlElicitErrorData
Latest MCP Protocol 2025_11_25 UrlElicitErrorData
UrlElicitationRequiredError
Latest MCP Protocol 2025_11_25 An error response that indicates that the server requires the client to provide additional information via an elicitation request.

Enums

ClientNotification
Latest MCP Protocol 2025_11_25 ClientNotification
ClientRequest
Latest MCP Protocol 2025_11_25 ClientRequest
ClientResult
Latest MCP Protocol 2025_11_25 ClientResult
CompleteRequestRef
Latest MCP Protocol 2025_11_25 CompleteRequestRef
ContentBlock
Latest MCP Protocol 2025_11_25 ContentBlock
CreateMessageContent
Latest MCP Protocol 2025_11_25 CreateMessageContent
ElicitRequestParams
Latest MCP Protocol 2025_11_25 The parameters for a request to elicit additional information from the user via the client.
ElicitResultAction
Latest MCP Protocol 2025_11_25 The user action in response to the elicitation.
ElicitResultContent
Latest MCP Protocol 2025_11_25 ElicitResultContent
ElicitResultContentPrimitive
Latest MCP Protocol 2025_11_25 ElicitResultContentPrimitive
EmbeddedResourceResource
Latest MCP Protocol 2025_11_25 EmbeddedResourceResource
EnumSchema
Latest MCP Protocol 2025_11_25 EnumSchema
IconTheme
Latest MCP Protocol 2025_11_25 Optional specifier for the theme this icon is designed for. light indicates the icon is designed to be used with a light background, and dark indicates the icon is designed to be used with a dark background. If not provided, the client should assume the icon can be used with any theme.
IncludeContext
Latest MCP Protocol 2025_11_25 A request to include context from one or more MCP servers (including the caller), to be attached to the prompt. The client MAY ignore this request. Default is “none”. Values “thisServer” and “allServers” are soft-deprecated. Servers SHOULD only use these values if the client declares ClientCapabilities.sampling.context. These values may be removed in future spec releases.
JsonrpcMessage
Latest MCP Protocol 2025_11_25 Refers to any valid JSON-RPC object that can be decoded off the wire, or encoded to be sent.
JsonrpcResponse
Latest MCP Protocol 2025_11_25 A response to a request, containing either the result or error.
LoggingLevel
Latest MCP Protocol 2025_11_25 The severity of a log message. These map to syslog message severities, as specified in RFC-5424: https://datatracker.ietf.org/doc/html/rfc5424#section-6.2.1
MultiSelectEnumSchema
Latest MCP Protocol 2025_11_25 MultiSelectEnumSchema
NumberSchemaType
Latest MCP Protocol 2025_11_25 NumberSchemaType
PrimitiveSchemaDefinition
Latest MCP Protocol 2025_11_25 Restricted schema definitions that only allow primitive types without nested objects or arrays.
ProgressToken
Latest MCP Protocol 2025_11_25 A progress token, used to associate progress notifications with the original request.
ProtocolVersion
ReadResourceContent
Latest MCP Protocol 2025_11_25 ReadResourceContent
RequestId
Latest MCP Protocol 2025_11_25 A uniquely identifying ID for a request in JSON-RPC.
Role
Latest MCP Protocol 2025_11_25 The sender or recipient of messages and data in a conversation.
SamplingMessageContent
Latest MCP Protocol 2025_11_25 SamplingMessageContent
SamplingMessageContentBlock
Latest MCP Protocol 2025_11_25 SamplingMessageContentBlock
ServerNotification
Latest MCP Protocol 2025_11_25 ServerNotification
ServerRequest
Latest MCP Protocol 2025_11_25 ServerRequest
ServerResult
Latest MCP Protocol 2025_11_25 ServerResult
SingleSelectEnumSchema
Latest MCP Protocol 2025_11_25 SingleSelectEnumSchema
StringSchemaFormat
Latest MCP Protocol 2025_11_25 StringSchemaFormat
TaskStatus
Latest MCP Protocol 2025_11_25 The status of a task.
ToolChoiceMode
Latest MCP Protocol 2025_11_25 Controls the tool use ability of the model:
ToolExecutionTaskSupport
Latest MCP Protocol 2025_11_25 Indicates whether this tool supports task-augmented execution. This allows clients to handle long-running operations through polling the task system.

Constants

INTERNAL_ERROR
Latest MCP Protocol 2025_11_25 Internal error. Internal JSON-RPC error.
INVALID_PARAMS
Latest MCP Protocol 2025_11_25 Invalid param. Invalid method parameter(s).
INVALID_REQUEST
Latest MCP Protocol 2025_11_25 Invalid Request. The JSON sent is not a valid Request object.
JSONRPC_VERSION
Latest MCP Protocol 2025_11_25 JSON-RPC Version
LATEST_PROTOCOL_VERSION
Latest MCP Protocol 2025_11_25 MCP Protocol Version
METHOD_NOT_FOUND
Latest MCP Protocol 2025_11_25 Method not found. The method does not exist / is not available.
PARSE_ERROR
Latest MCP Protocol 2025_11_25 Parse error. Invalid JSON was received. An error occurred while parsing the JSON text.
URL_ELICITATION_REQUIRED
Latest MCP Protocol 2025_11_25 The server cannot proceed without additional client input.

Type Aliases

ClientCapabilitiesRootsDeprecated
Latest MCP Protocol 2025_11_25
CompleteRequestParamsArgumentDeprecated
Latest MCP Protocol 2025_11_25
CompleteRequestParamsContextDeprecated
Latest MCP Protocol 2025_11_25
CompleteRequestParamsRefDeprecated
Latest MCP Protocol 2025_11_25
CreateMessageRequestParamsIncludeContextDeprecated
Latest MCP Protocol 2025_11_25 Deprecating the old auto-generated verbose names. These were renamed to clearer, shorter names in v0.8.0. The old names are deprecated but kept for backward-compatibility for a smooth migration period.
CreateMessageResultContentDeprecated
Latest MCP Protocol 2025_11_25
ElicitResultContentValueDeprecated
Latest MCP Protocol 2025_11_25
GenericResult
Latest MCP Protocol 2025_11_25 Alias to avoid conflicts with Rust’s standard Result type.
ReadResourceResultContentsItemDeprecated
Latest MCP Protocol 2025_11_25