pub struct CallToolResult {
pub content: Vec<ContentBlock>,
pub is_error: Option<bool>,
pub meta: Option<ResultMetaObject>,
pub result_type: String,
pub structured_content: Option<Value>,
}Expand description
Latest MCP Protocol 2026_07_28 The result returned by the server for a {@link CallToolRequesttools/call} request.
JSON schema
{
"description": "The result returned by the server for a {@link CallToolRequesttools/call} request.",
"type": "object",
"required": [
"content",
"resultType"
],
"properties": {
"_meta": {
"$ref": "#/$defs/ResultMetaObject"
},
"content": {
"description": "A list of content objects that represent the unstructured result of the tool call.",
"type": "array",
"items": {
"$ref": "#/$defs/ContentBlock"
}
},
"isError": {
"description": "Whether the tool call ended in an error.\n\nIf not set, this is assumed to be false (the call was successful).\n\nAny errors that originate from the tool SHOULD be reported inside the result\nobject, with isError set to true, _not_ as an MCP protocol-level error\nresponse. Otherwise, the LLM would not be able to see that an error occurred\nand self-correct.\n\nHowever, any errors in _finding_ the tool, an error indicating that the\nserver does not support tool calls, or any other exceptional conditions,\nshould be reported as an MCP error response.",
"type": "boolean"
},
"resultType": {
"description": "Indicates the type of the result, which allows the client to determine\nhow to parse the result object.\n\nServers implementing this protocol version MUST include this field.\nFor backward compatibility, when a client receives a result from a\nserver implementing an earlier protocol version (which does not include\nresultType), the client MUST treat the absent field as \"complete\".",
"type": "string"
},
"structuredContent": {
"description": "An optional JSON value that represents the structured result of the tool call.\n\nThis can be any JSON value (object, array, string, number, boolean, or null)\nthat conforms to the tool's outputSchema if one is defined."
}
}
}Fields
content: Vec<ContentBlock>A list of content objects that represent the unstructured result of the tool call.
is_error: Option<bool>Whether the tool call ended in an error. If not set, this is assumed to be false (the call was successful). Any errors that originate from the tool SHOULD be reported inside the result object, with isError set to true, not as an MCP protocol-level error response. Otherwise, the LLM would not be able to see that an error occurred and self-correct. However, any errors in finding the tool, an error indicating that the server does not support tool calls, or any other exceptional conditions, should be reported as an MCP error response.
meta: Option<ResultMetaObject>result_type: StringIndicates the type of the result, which allows the client to determine how to parse the result object. Servers implementing this protocol version MUST include this field. For backward compatibility, when a client receives a result from a server implementing an earlier protocol version (which does not include resultType), the client MUST treat the absent field as “complete”.
structured_content: Option<Value>An optional JSON value that represents the structured result of the tool call. This can be any JSON value (object, array, string, number, boolean, or null) that conforms to the tool’s outputSchema if one is defined.
Implementations
Sourceimpl CallToolResult
impl CallToolResult
pub fn text_content(content: Vec<TextContent>) -> Self
pub fn image_content(content: Vec<ImageContent>) -> Self
pub fn audio_content(content: Vec<AudioContent>) -> Self
pub fn resource_link(content: Vec<ResourceLink>) -> Self
pub fn embedded_resource(content: Vec<EmbeddedResource>) -> Self
pub fn with_error(error: CallToolError) -> Self
pub fn with_meta(self, meta: Option<ResultMetaObject>) -> Self
pub fn with_structured_content( self, structured_content: Map<String, Value>, ) -> Self
pub fn from_content(content: Vec<ContentBlock>) -> Self
pub fn add_content(self, content: ContentBlock) -> Self