pub struct CompleteResult {
pub completion: CompleteResultCompletion,
pub meta: Option<ResultMetaObject>,
pub result_type: String,
}Expand description
Latest MCP Protocol 2026_07_28 The result returned by the server for a {@link CompleteRequestcompletion/complete} request.
JSON schema
{
"description": "The result returned by the server for a {@link CompleteRequestcompletion/complete} request.",
"type": "object",
"required": [
"completion",
"resultType"
],
"properties": {
"_meta": {
"$ref": "#/$defs/ResultMetaObject"
},
"completion": {
"type": "object",
"required": [
"values"
],
"properties": {
"hasMore": {
"description": "Indicates whether there are additional completion options beyond those provided in the current response, even if the exact total is unknown.",
"type": "boolean"
},
"total": {
"description": "The total number of completion options available. This can exceed the number of values actually sent in the response.",
"type": "integer"
},
"values": {
"description": "An array of completion values. Must not exceed 100 items.",
"type": "array",
"items": {
"type": "string"
},
"maxItems": 100
}
}
},
"resultType": {
"description": "Indicates the type of the result, which allows the client to determine\nhow to parse the result object.\n\nServers implementing this protocol version MUST include this field.\nFor backward compatibility, when a client receives a result from a\nserver implementing an earlier protocol version (which does not include\nresultType), the client MUST treat the absent field as \"complete\".",
"type": "string"
}
}
}Fields
completion: CompleteResultCompletionmeta: Option<ResultMetaObject>result_type: StringIndicates the type of the result, which allows the client to determine how to parse the result object. Servers implementing this protocol version MUST include this field. For backward compatibility, when a client receives a result from a server implementing an earlier protocol version (which does not include resultType), the client MUST treat the absent field as “complete”.