pub struct CreateMessageRequestParams {
pub include_context: Option<IncludeContext>,
pub max_tokens: i64,
pub messages: Vec<SamplingMessage>,
pub metadata: Option<JsonObject>,
pub model_preferences: Option<ModelPreferences>,
pub stop_sequences: Vec<String>,
pub system_prompt: Option<String>,
pub temperature: Option<f64>,
pub tool_choice: Option<ToolChoice>,
pub tools: Vec<Tool>,
}Expand description
Latest MCP Protocol 2026_07_28 Parameters for a sampling/createMessage request.
JSON schema
{
"description": "Parameters for a sampling/createMessage request.",
"type": "object",
"required": [
"maxTokens",
"messages"
],
"properties": {
"includeContext": {
"description": "A request to include context from one or more MCP servers (including the caller), to be attached to the prompt.\nThe client MAY ignore this request.\n\nDefault is \"none\". The values \"thisServer\" and \"allServers\" are deprecated (SEP-2596): servers SHOULD\nomit this field or use \"none\", and SHOULD only use the deprecated values if the client declares\n{@link ClientCapabilities.sampling.context}.",
"type": "string",
"enum": [
"allServers",
"none",
"thisServer"
]
},
"maxTokens": {
"description": "The requested maximum number of tokens to sample (to prevent runaway completions).\n\nThe client MAY choose to sample fewer tokens than the requested maximum.",
"type": "integer"
},
"messages": {
"type": "array",
"items": {
"$ref": "#/$defs/SamplingMessage"
}
},
"metadata": {
"description": "Optional metadata to pass through to the LLM provider. The format of this metadata is provider-specific.",
"$ref": "#/$defs/JSONObject"
},
"modelPreferences": {
"description": "The server's preferences for which model to select. The client MAY ignore these preferences.",
"$ref": "#/$defs/ModelPreferences"
},
"stopSequences": {
"type": "array",
"items": {
"type": "string"
}
},
"systemPrompt": {
"description": "An optional system prompt the server wants to use for sampling. The client MAY modify or omit this prompt.",
"type": "string"
},
"temperature": {
"type": "number"
},
"toolChoice": {
"description": "Controls how the model uses tools.\nThe client MUST return an error if this field is provided but {@link ClientCapabilities.sampling.tools} is not declared.\nDefault is { mode: \"auto\" }.",
"$ref": "#/$defs/ToolChoice"
},
"tools": {
"description": "Tools that the model may use during generation.\nThe client MUST return an error if this field is provided but {@link ClientCapabilities.sampling.tools} is not declared.",
"type": "array",
"items": {
"$ref": "#/$defs/Tool"
}
}
}
}Fields
include_context: Option<IncludeContext>A request to include context from one or more MCP servers (including the caller), to be attached to the prompt. The client MAY ignore this request. Default is “none”. The values “thisServer” and “allServers” are deprecated (SEP-2596): servers SHOULD omit this field or use “none”, and SHOULD only use the deprecated values if the client declares {@link ClientCapabilities.sampling.context}.
max_tokens: i64The requested maximum number of tokens to sample (to prevent runaway completions). The client MAY choose to sample fewer tokens than the requested maximum.
messages: Vec<SamplingMessage>metadata: Option<JsonObject>Optional metadata to pass through to the LLM provider. The format of this metadata is provider-specific.
model_preferences: Option<ModelPreferences>The server’s preferences for which model to select. The client MAY ignore these preferences.
stop_sequences: Vec<String>system_prompt: Option<String>An optional system prompt the server wants to use for sampling. The client MAY modify or omit this prompt.
temperature: Option<f64>tool_choice: Option<ToolChoice>Controls how the model uses tools. The client MUST return an error if this field is provided but {@link ClientCapabilities.sampling.tools} is not declared. Default is { mode: “auto” }.
tools: Vec<Tool>Tools that the model may use during generation. The client MUST return an error if this field is provided but {@link ClientCapabilities.sampling.tools} is not declared.