HeaderMismatchError

Struct HeaderMismatchError 

pub struct HeaderMismatchError {
    pub error: RpcError,
    pub id: Option<RequestId>,
    /* private fields */
}
Latest MCP Protocol 2026_07_28 Returned when a server rejects a request because the values in the HTTP headers do not match the corresponding values in the request body, or because required headers are missing or malformed. For HTTP, the response status code MUST be 400 Bad Request.

JSON schema
{
 "description": "Returned when a server rejects a request because the values in the HTTP\nheaders do not match the corresponding values in the request body, or\nbecause required headers are missing or malformed. For HTTP, the response\nstatus code MUST be 400 Bad Request.",
 "type": "object",
 "required": [
   "error",
   "jsonrpc"
 ],
 "properties": {
   "error": {
     "allOf": [
       {
         "$ref": "#/$defs/Error"
       },
       {
         "type": "object",
         "required": [
           "code"
         ],
         "properties": {
           "code": {
             "type": "integer"
           }
         }
       }
     ]
   },
   "id": {
     "$ref": "#/$defs/RequestId"
   },
   "jsonrpc": {
     "type": "string",
     "const": "2.0"
   }
 }
}

Fields

error: RpcErrorid: Option<RequestId>

Implementations

Source

impl HeaderMismatchError

pub fn new(error: RpcError, id: Option<RequestId>) -> Self

pub fn jsonrpc(&self) -> &String