pub struct Result {
pub meta: Option<ResultMetaObject>,
pub result_type: String,
pub extra: Option<Map<String, Value>>,
}Expand description
Latest MCP Protocol 2026_07_28 Common result fields.
JSON schema
{
"description": "Common result fields.",
"type": "object",
"required": [
"resultType"
],
"properties": {
"_meta": {
"$ref": "#/$defs/ResultMetaObject"
},
"resultType": {
"description": "Indicates the type of the result, which allows the client to determine\nhow to parse the result object.\n\nServers implementing this protocol version MUST include this field.\nFor backward compatibility, when a client receives a result from a\nserver implementing an earlier protocol version (which does not include\nresultType), the client MUST treat the absent field as \"complete\".",
"type": "string"
}
},
"additionalProperties": {}
}Fields
meta: Option<ResultMetaObject>result_type: StringIndicates the type of the result, which allows the client to determine how to parse the result object. Servers implementing this protocol version MUST include this field. For backward compatibility, when a client receives a result from a server implementing an earlier protocol version (which does not include resultType), the client MUST treat the absent field as “complete”.
extra: Option<Map<String, Value>>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Result
impl<'de> Deserialize<'de> for Result
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<Result> for ServerResult
impl From<Result> for ServerResult
Sourceimpl From<Result> for ResultFromClient
impl From<Result> for ResultFromClient
Sourceimpl From<Result> for MessageFromClient
impl From<Result> for MessageFromClient
Sourceimpl From<Result> for MessageFromServer
impl From<Result> for MessageFromServer