pub struct SubscriptionsListenRequestParams {
pub meta: RequestMetaObject,
pub notifications: SubscriptionFilter,
}Expand description
Latest MCP Protocol 2026_07_28 Parameters for a {@link SubscriptionsListenRequestsubscriptions/listen} request.
JSON schema
{
"description": "Parameters for a {@link SubscriptionsListenRequestsubscriptions/listen} request.",
"type": "object",
"required": [
"_meta",
"notifications"
],
"properties": {
"_meta": {
"$ref": "#/$defs/RequestMetaObject"
},
"notifications": {
"description": "The notifications the client opts in to on this stream. The server\n**MUST NOT** send notification types the client has not explicitly\nrequested.",
"$ref": "#/$defs/SubscriptionFilter"
}
}
}Fields
meta: RequestMetaObjectnotifications: SubscriptionFilterThe notifications the client opts in to on this stream. The server MUST NOT send notification types the client has not explicitly requested.