pub struct UnsupportedProtocolVersionError {
pub error: UnsupportedProtocolVersionErrorError,
pub id: Option<RequestId>,
/* private fields */
}Expand description
Latest MCP Protocol 2026_07_28 Returned when the request’s protocol version is unknown to the server or unsupported (e.g., a known experimental or draft version the server has chosen not to implement). For HTTP, the response status code MUST be 400 Bad Request.
JSON schema
{
"description": "Returned when the request's protocol version is unknown to the server or\nunsupported (e.g., a known experimental or draft version the server has\nchosen not to implement). For HTTP, the response status code MUST be\n400 Bad Request.",
"type": "object",
"required": [
"error",
"jsonrpc"
],
"properties": {
"error": {
"allOf": [
{
"$ref": "#/$defs/Error"
},
{
"type": "object",
"required": [
"code",
"data"
],
"properties": {
"code": {
"type": "integer"
},
"data": {
"type": "object",
"required": [
"requested",
"supported"
],
"properties": {
"requested": {
"description": "The protocol version that was requested by the client.",
"type": "string"
},
"supported": {
"description": "Protocol versions the server supports. The client should choose a\nmutually supported version from this list and retry.",
"type": "array",
"items": {
"type": "string"
}
}
}
}
}
}
]
},
"id": {
"$ref": "#/$defs/RequestId"
},
"jsonrpc": {
"type": "string",
"const": "2.0"
}
}
}Fields
error: UnsupportedProtocolVersionErrorErrorid: Option<RequestId>Implementations