pub type GenericResult = Result;Expand description
Latest MCP Protocol 2026_07_28
Alias to avoid conflicts with Rust’s standard Result type.
Aliased Type
pub struct GenericResult {
pub meta: Option<ResultMetaObject>,
pub result_type: String,
pub extra: Option<Map<String, Value>>,
}Fields
meta: Option<ResultMetaObject>result_type: StringIndicates the type of the result, which allows the client to determine how to parse the result object. Servers implementing this protocol version MUST include this field. For backward compatibility, when a client receives a result from a server implementing an earlier protocol version (which does not include resultType), the client MUST treat the absent field as “complete”.
extra: Option<Map<String, Value>>Trait Implementations
Sourceimpl From<CallToolResult> for GenericResult
impl From<CallToolResult> for GenericResult
Sourcefn from(value: CallToolResult) -> Self
fn from(value: CallToolResult) -> Self
Converts to this type from the input type.
Sourceimpl From<CompleteResult> for GenericResult
impl From<CompleteResult> for GenericResult
Sourcefn from(value: CompleteResult) -> Self
fn from(value: CompleteResult) -> Self
Converts to this type from the input type.
Sourceimpl From<DiscoverResult> for GenericResult
impl From<DiscoverResult> for GenericResult
Sourcefn from(value: DiscoverResult) -> Self
fn from(value: DiscoverResult) -> Self
Converts to this type from the input type.
Sourceimpl From<GetPromptResult> for GenericResult
impl From<GetPromptResult> for GenericResult
Sourcefn from(value: GetPromptResult) -> Self
fn from(value: GetPromptResult) -> Self
Converts to this type from the input type.
Sourceimpl From<InputRequiredResult> for GenericResult
impl From<InputRequiredResult> for GenericResult
Sourcefn from(value: InputRequiredResult) -> Self
fn from(value: InputRequiredResult) -> Self
Converts to this type from the input type.
Sourceimpl From<ListPromptsResult> for GenericResult
impl From<ListPromptsResult> for GenericResult
Sourcefn from(value: ListPromptsResult) -> Self
fn from(value: ListPromptsResult) -> Self
Converts to this type from the input type.
Sourceimpl From<ListResourceTemplatesResult> for GenericResult
impl From<ListResourceTemplatesResult> for GenericResult
Sourcefn from(value: ListResourceTemplatesResult) -> Self
fn from(value: ListResourceTemplatesResult) -> Self
Converts to this type from the input type.
Sourceimpl From<ListResourcesResult> for GenericResult
impl From<ListResourcesResult> for GenericResult
Sourcefn from(value: ListResourcesResult) -> Self
fn from(value: ListResourcesResult) -> Self
Converts to this type from the input type.
Sourceimpl From<ListToolsResult> for GenericResult
impl From<ListToolsResult> for GenericResult
Sourcefn from(value: ListToolsResult) -> Self
fn from(value: ListToolsResult) -> Self
Converts to this type from the input type.
Sourceimpl From<ReadResourceResult> for GenericResult
impl From<ReadResourceResult> for GenericResult
Sourcefn from(value: ReadResourceResult) -> Self
fn from(value: ReadResourceResult) -> Self
Converts to this type from the input type.
Sourceimpl From<SubscriptionsListenResult> for GenericResult
impl From<SubscriptionsListenResult> for GenericResult
Sourcefn from(value: SubscriptionsListenResult) -> Self
fn from(value: SubscriptionsListenResult) -> Self
Converts to this type from the input type.